Struct HdfsNative
pub struct HdfsNative {
pub(crate) config: HdfsNativeConfig,
}Expand description
Hadoop Distributed File System (HDFS™) support. Using Native Rust HDFS client. A distributed file system that provides high-throughput access to application data. Using Native Rust HDFS client.
Capabilities
Depending on its configuration and the backing system, this service can expose:
- create_dir
- stat
- read
- write
- delete
- list
- copy
- rename
-
presign
Inspect the effective capability set with opendal_core::Operator::info and
[opendal_core::OperatorInfo::capability] after building an operator.
Configuration
Use crate::HdfsNativeConfig for serializable configuration and this builder’s
methods for direct construction. The field and method documentation defines
accepted values, defaults, and environment interaction.
Fields
config: HdfsNativeConfigImplementations
impl HdfsNativeBuilder
impl HdfsNativeBuilder
pub fn root(self, root: &str) -> HdfsNativeBuilder
pub fn root(self, root: &str) -> HdfsNativeBuilder
Set root of this backend.
All operations will happen under this root.
pub fn name_node(self, name_node: &str) -> HdfsNativeBuilder
pub fn name_node(self, name_node: &str) -> HdfsNativeBuilder
Set name_node of this backend.
Valid format including:
default: using the default setting based on hadoop config.hdfs://127.0.0.1:9000: connect to hdfs cluster.hdfs://namenode1:9000,namenode2:9000: connect to hdfs ha cluster.
pub fn enable_append(self, _enable_append: bool) -> HdfsNativeBuilder
👎Deprecated since 0.57.0: HDFS Native append capability is enabled by default and this option is no longer needed.
pub fn enable_append(self, _enable_append: bool) -> HdfsNativeBuilder
HDFS Native append capability is enabled by default and this option is no longer needed.
Deprecated: HDFS Native append capability is enabled by default.
pub fn options(self, options: HashMap<String, String>) -> HdfsNativeBuilder
pub fn options(self, options: HashMap<String, String>) -> HdfsNativeBuilder
Set other hdfs-native client options of this backend.
See the hdfs-native documentation for the supported options.